@@ -27,23 +27,28 @@ the default database and collection to use (see connection `azure_cosmos_default
 from __future__ import annotations
 
 import uuid
-from typing import TYPE_CHECKING, Any, Union
+from typing import TYPE_CHECKING, Any, cast
 from urllib.parse import urlparse
 
-from airflow.exceptions import AirflowBadRequest, AirflowException
-from airflow.hooks.base import BaseHook
-from airflow.providers.microsoft.azure.utils import (
-    add_managed_identity_connection_widgets,
-    get_field,
-    get_sync_default_azure_credential,
-)
 from azure.cosmos import PartitionKey
 from azure.cosmos.cosmos_client import CosmosClient
 from azure.cosmos.exceptions import CosmosHttpResponseError
 from azure.mgmt.cosmosdb import CosmosDBManagementClient
 
+from airflow.exceptions import AirflowBadRequest, AirflowException
+from airflow.providers.microsoft.azure.utils import (
+    add_managed_identity_connection_widgets,
+    get_field,
+    get_sync_default_azure_credential,
+)
+
+try:
+    from airflow.sdk import BaseHook
+except ImportError:
+    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+
 if TYPE_CHECKING:
-    PartitionKeyType = Union[str, list[str]]
+    PartitionKeyType = str | list[str]
 
 
 class AzureCosmosDBHook(BaseHook):
@@ -130,6 +135,7 @@ class AzureCosmosDBHook(BaseHook):
             conn = self.get_connection(self.conn_id)
             extras = conn.extra_dejson
             endpoint_uri = conn.login
+            endpoint_uri = cast("str", endpoint_uri)
             resource_group_name = self._get_field(extras, "resource_group_name")
 
             if conn.password:
@@ -146,12 +152,12 @@ class AzureCosmosDBHook(BaseHook):
                     credential=credential,
                     subscription_id=subscritption_id,
                 )
-
+                conn.login = cast("str", conn.login)
                 database_account = urlparse(conn.login).netloc.split(".")[0]
                 database_account_keys = management_client.database_accounts.list_keys(
                     resource_group_name, database_account
                 )
-                master_key = database_account_keys.primary_master_key
+                master_key = cast("str", database_account_keys.primary_master_key)
             else:
                 raise AirflowException("Either password or resource_group_name is required")
 
